# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .control_tower_aws_account import *
from .provider import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import lbrlabs_pulumi_aws_controltower.config as __config
    config = __config
else:
    config = _utilities.lazy_import('lbrlabs_pulumi_aws_controltower.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "awscontroltower",
  "mod": "index/controlTowerAwsAccount",
  "fqn": "lbrlabs_pulumi_aws_controltower",
  "classes": {
   "awscontroltower:index/controlTowerAwsAccount:controlTowerAwsAccount": "ControlTowerAwsAccount"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "awscontroltower",
  "token": "pulumi:providers:awscontroltower",
  "fqn": "lbrlabs_pulumi_aws_controltower",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

import types

__config__ = pulumi.Config('awscontroltower')


class _ExportableConfig(types.ModuleType):
    @property
    def access_key(self) -> Optional[str]:
        """
        This is the AWS access key. It must be provided, but it can also be sourced from the `AWS_ACCESS_KEY_ID` environment
        variable, or via a shared credentials file if `profile` is specified.
        """
        return __config__.get('accessKey')

    @property
    def assume_role(self) -> Optional[str]:
        """
        Settings for making use of the AWS Assume Role functionality.
        """
        return __config__.get('assumeRole')

    @property
    def max_retries(self) -> Optional[int]:
        """
        This is the maximum number of times an API call is retried, in the case where requests are being throttled or
        experiencing transient failures. The delay between the subsequent API calls increases exponentially. If omitted, the
        default value is `25`.
        """
        return __config__.get_int('maxRetries')

    @property
    def profile(self) -> Optional[str]:
        """
        This is the AWS profile name as set in the shared credentials file.
        """
        return __config__.get('profile')

    @property
    def region(self) -> Optional[str]:
        """
        This is the AWS region. It must be provided, but it can also be sourced from the `AWS_DEFAULT_REGION` environment
        variables, or via a shared credentials file if `profile` is specified.
        """
        return __config__.get('region')

    @property
    def secret_key(self) -> Optional[str]:
        """
        This is the AWS secret key. It must be provided, but it can also be sourced from the `AWS_SECRET_ACCESS_KEY` environment
        variable, or via a shared credentials file if `profile` is specified.
        """
        return __config__.get('secretKey')

    @property
    def shared_credentials_file(self) -> Optional[str]:
        """
        This is the path to the shared credentials file. If this is not set and a profile is specified, `~/.aws/credentials`
        will be used.
        """
        return __config__.get('sharedCredentialsFile')

    @property
    def skip_credentials_validation(self) -> Optional[bool]:
        """
        Skip the credentials validation via the STS API. Useful for AWS API implementations that do not have STS available or
        implemented.
        """
        return __config__.get_bool('skipCredentialsValidation')

    @property
    def skip_metadata_api_check(self) -> Optional[bool]:
        """
        Skip the AWS Metadata API check. Useful for AWS API implementations that do not have a metadata API endpoint. Setting to
        `true` prevents Terraform from authenticating via the Metadata API. You may need to use other authentication methods
        like static credentials, configuration variables, or environment variables.
        """
        return __config__.get_bool('skipMetadataApiCheck')

    @property
    def skip_requesting_account_id(self) -> Optional[bool]:
        """
        Skip requesting the account ID. Useful for AWS API implementations that do not have the IAM, STS API, or metadata API.
        """
        return __config__.get_bool('skipRequestingAccountId')

    @property
    def token(self) -> Optional[str]:
        """
        Session token for validating temporary credentials. Typically provided after successful identity federation or
        Multi-Factor Authentication (MFA) login. With MFA login, this is the session token provided afterward, not the 6 digit
        MFA code used to get temporary credentials. It can also be sourced from the `AWS_SESSION_TOKEN` environment variable.
        """
        return __config__.get('token')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'ControlTowerAwsAccountSso',
]

@pulumi.output_type
class ControlTowerAwsAccountSso(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "firstName":
            suggest = "first_name"
        elif key == "lastName":
            suggest = "last_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ControlTowerAwsAccountSso. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ControlTowerAwsAccountSso.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ControlTowerAwsAccountSso.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 email: str,
                 first_name: str,
                 last_name: str):
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "first_name", first_name)
        pulumi.set(__self__, "last_name", last_name)

    @property
    @pulumi.getter
    def email(self) -> str:
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> str:
        return pulumi.get(self, "first_name")

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> str:
        return pulumi.get(self, "last_name")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'AssumeRole',
]

@pulumi.output_type
class AssumeRole(dict):
    def __init__(__self__, *,
                 duration_seconds: Optional[int] = None,
                 external_id: Optional[str] = None,
                 policy: Optional[str] = None,
                 policy_arns: Optional[Sequence[str]] = None,
                 role_arn: Optional[str] = None,
                 session_name: Optional[str] = None,
                 tags: Optional[Mapping[str, str]] = None,
                 transitive_tag_keys: Optional[Sequence[str]] = None):
        if duration_seconds is not None:
            pulumi.set(__self__, "duration_seconds", duration_seconds)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if policy_arns is not None:
            pulumi.set(__self__, "policy_arns", policy_arns)
        if role_arn is not None:
            pulumi.set(__self__, "role_arn", role_arn)
        if session_name is not None:
            pulumi.set(__self__, "session_name", session_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transitive_tag_keys is not None:
            pulumi.set(__self__, "transitive_tag_keys", transitive_tag_keys)

    @property
    @pulumi.getter(name="durationSeconds")
    def duration_seconds(self) -> Optional[int]:
        return pulumi.get(self, "duration_seconds")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[str]:
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter
    def policy(self) -> Optional[str]:
        return pulumi.get(self, "policy")

    @property
    @pulumi.getter(name="policyArns")
    def policy_arns(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "policy_arns")

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> Optional[str]:
        return pulumi.get(self, "role_arn")

    @property
    @pulumi.getter(name="sessionName")
    def session_name(self) -> Optional[str]:
        return pulumi.get(self, "session_name")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, str]]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="transitiveTagKeys")
    def transitive_tag_keys(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "transitive_tag_keys")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ControlTowerAwsAccountArgs', 'ControlTowerAwsAccount']

@pulumi.input_type
class ControlTowerAwsAccountArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[str],
                 organizational_unit: pulumi.Input[str],
                 sso: pulumi.Input['ControlTowerAwsAccountSsoArgs'],
                 close_account_on_delete: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organizational_unit_id_on_delete: Optional[pulumi.Input[str]] = None,
                 path_id: Optional[pulumi.Input[str]] = None,
                 provisioned_product_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a ControlTowerAwsAccount resource.
        :param pulumi.Input[str] email: Root email of the account.
        :param pulumi.Input[str] organizational_unit: Name of the Organizational Unit under which the account resides.
        :param pulumi.Input['ControlTowerAwsAccountSsoArgs'] sso: Assigned SSO user settings.
        :param pulumi.Input[bool] close_account_on_delete: If enabled, this will close the AWS account on resource deletion, beginning the 90-day suspension period. Otherwise, the
               account will just be unenrolled from Control Tower.
        :param pulumi.Input[str] name: Name of the account.
        :param pulumi.Input[str] organizational_unit_id_on_delete: ID of the Organizational Unit to which the account should be moved when the resource is deleted. If no value is
               provided, the account will not be moved.
        :param pulumi.Input[str] path_id: Name of the path identifier of the product. This value is optional if the product has a default path, and required if
               the product has more than one path. To list the paths for a product, use ListLaunchPaths.
        :param pulumi.Input[str] provisioned_product_name: Name of the service catalog product that is provisioned. Defaults to a slugified version of the account name.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value map of resource tags for the account.
        """
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "organizational_unit", organizational_unit)
        pulumi.set(__self__, "sso", sso)
        if close_account_on_delete is not None:
            pulumi.set(__self__, "close_account_on_delete", close_account_on_delete)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organizational_unit_id_on_delete is not None:
            pulumi.set(__self__, "organizational_unit_id_on_delete", organizational_unit_id_on_delete)
        if path_id is not None:
            pulumi.set(__self__, "path_id", path_id)
        if provisioned_product_name is not None:
            pulumi.set(__self__, "provisioned_product_name", provisioned_product_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[str]:
        """
        Root email of the account.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="organizationalUnit")
    def organizational_unit(self) -> pulumi.Input[str]:
        """
        Name of the Organizational Unit under which the account resides.
        """
        return pulumi.get(self, "organizational_unit")

    @organizational_unit.setter
    def organizational_unit(self, value: pulumi.Input[str]):
        pulumi.set(self, "organizational_unit", value)

    @property
    @pulumi.getter
    def sso(self) -> pulumi.Input['ControlTowerAwsAccountSsoArgs']:
        """
        Assigned SSO user settings.
        """
        return pulumi.get(self, "sso")

    @sso.setter
    def sso(self, value: pulumi.Input['ControlTowerAwsAccountSsoArgs']):
        pulumi.set(self, "sso", value)

    @property
    @pulumi.getter(name="closeAccountOnDelete")
    def close_account_on_delete(self) -> Optional[pulumi.Input[bool]]:
        """
        If enabled, this will close the AWS account on resource deletion, beginning the 90-day suspension period. Otherwise, the
        account will just be unenrolled from Control Tower.
        """
        return pulumi.get(self, "close_account_on_delete")

    @close_account_on_delete.setter
    def close_account_on_delete(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "close_account_on_delete", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the account.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="organizationalUnitIdOnDelete")
    def organizational_unit_id_on_delete(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the Organizational Unit to which the account should be moved when the resource is deleted. If no value is
        provided, the account will not be moved.
        """
        return pulumi.get(self, "organizational_unit_id_on_delete")

    @organizational_unit_id_on_delete.setter
    def organizational_unit_id_on_delete(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organizational_unit_id_on_delete", value)

    @property
    @pulumi.getter(name="pathId")
    def path_id(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the path identifier of the product. This value is optional if the product has a default path, and required if
        the product has more than one path. To list the paths for a product, use ListLaunchPaths.
        """
        return pulumi.get(self, "path_id")

    @path_id.setter
    def path_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path_id", value)

    @property
    @pulumi.getter(name="provisionedProductName")
    def provisioned_product_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the service catalog product that is provisioned. Defaults to a slugified version of the account name.
        """
        return pulumi.get(self, "provisioned_product_name")

    @provisioned_product_name.setter
    def provisioned_product_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "provisioned_product_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Key-value map of resource tags for the account.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ControlTowerAwsAccountState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[str]] = None,
                 close_account_on_delete: Optional[pulumi.Input[bool]] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organizational_unit: Optional[pulumi.Input[str]] = None,
                 organizational_unit_id_on_delete: Optional[pulumi.Input[str]] = None,
                 path_id: Optional[pulumi.Input[str]] = None,
                 provisioned_product_name: Optional[pulumi.Input[str]] = None,
                 sso: Optional[pulumi.Input['ControlTowerAwsAccountSsoArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering ControlTowerAwsAccount resources.
        :param pulumi.Input[str] account_id: ID of the AWS account.
        :param pulumi.Input[bool] close_account_on_delete: If enabled, this will close the AWS account on resource deletion, beginning the 90-day suspension period. Otherwise, the
               account will just be unenrolled from Control Tower.
        :param pulumi.Input[str] email: Root email of the account.
        :param pulumi.Input[str] name: Name of the account.
        :param pulumi.Input[str] organizational_unit: Name of the Organizational Unit under which the account resides.
        :param pulumi.Input[str] organizational_unit_id_on_delete: ID of the Organizational Unit to which the account should be moved when the resource is deleted. If no value is
               provided, the account will not be moved.
        :param pulumi.Input[str] path_id: Name of the path identifier of the product. This value is optional if the product has a default path, and required if
               the product has more than one path. To list the paths for a product, use ListLaunchPaths.
        :param pulumi.Input[str] provisioned_product_name: Name of the service catalog product that is provisioned. Defaults to a slugified version of the account name.
        :param pulumi.Input['ControlTowerAwsAccountSsoArgs'] sso: Assigned SSO user settings.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value map of resource tags for the account.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if close_account_on_delete is not None:
            pulumi.set(__self__, "close_account_on_delete", close_account_on_delete)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organizational_unit is not None:
            pulumi.set(__self__, "organizational_unit", organizational_unit)
        if organizational_unit_id_on_delete is not None:
            pulumi.set(__self__, "organizational_unit_id_on_delete", organizational_unit_id_on_delete)
        if path_id is not None:
            pulumi.set(__self__, "path_id", path_id)
        if provisioned_product_name is not None:
            pulumi.set(__self__, "provisioned_product_name", provisioned_product_name)
        if sso is not None:
            pulumi.set(__self__, "sso", sso)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the AWS account.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="closeAccountOnDelete")
    def close_account_on_delete(self) -> Optional[pulumi.Input[bool]]:
        """
        If enabled, this will close the AWS account on resource deletion, beginning the 90-day suspension period. Otherwise, the
        account will just be unenrolled from Control Tower.
        """
        return pulumi.get(self, "close_account_on_delete")

    @close_account_on_delete.setter
    def close_account_on_delete(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "close_account_on_delete", value)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[str]]:
        """
        Root email of the account.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the account.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="organizationalUnit")
    def organizational_unit(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Organizational Unit under which the account resides.
        """
        return pulumi.get(self, "organizational_unit")

    @organizational_unit.setter
    def organizational_unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organizational_unit", value)

    @property
    @pulumi.getter(name="organizationalUnitIdOnDelete")
    def organizational_unit_id_on_delete(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the Organizational Unit to which the account should be moved when the resource is deleted. If no value is
        provided, the account will not be moved.
        """
        return pulumi.get(self, "organizational_unit_id_on_delete")

    @organizational_unit_id_on_delete.setter
    def organizational_unit_id_on_delete(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organizational_unit_id_on_delete", value)

    @property
    @pulumi.getter(name="pathId")
    def path_id(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the path identifier of the product. This value is optional if the product has a default path, and required if
        the product has more than one path. To list the paths for a product, use ListLaunchPaths.
        """
        return pulumi.get(self, "path_id")

    @path_id.setter
    def path_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path_id", value)

    @property
    @pulumi.getter(name="provisionedProductName")
    def provisioned_product_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the service catalog product that is provisioned. Defaults to a slugified version of the account name.
        """
        return pulumi.get(self, "provisioned_product_name")

    @provisioned_product_name.setter
    def provisioned_product_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "provisioned_product_name", value)

    @property
    @pulumi.getter
    def sso(self) -> Optional[pulumi.Input['ControlTowerAwsAccountSsoArgs']]:
        """
        Assigned SSO user settings.
        """
        return pulumi.get(self, "sso")

    @sso.setter
    def sso(self, value: Optional[pulumi.Input['ControlTowerAwsAccountSsoArgs']]):
        pulumi.set(self, "sso", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Key-value map of resource tags for the account.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


class ControlTowerAwsAccount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 close_account_on_delete: Optional[pulumi.Input[bool]] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organizational_unit: Optional[pulumi.Input[str]] = None,
                 organizational_unit_id_on_delete: Optional[pulumi.Input[str]] = None,
                 path_id: Optional[pulumi.Input[str]] = None,
                 provisioned_product_name: Optional[pulumi.Input[str]] = None,
                 sso: Optional[pulumi.Input[pulumi.InputType['ControlTowerAwsAccountSsoArgs']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Create a ControlTowerAwsAccount resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] close_account_on_delete: If enabled, this will close the AWS account on resource deletion, beginning the 90-day suspension period. Otherwise, the
               account will just be unenrolled from Control Tower.
        :param pulumi.Input[str] email: Root email of the account.
        :param pulumi.Input[str] name: Name of the account.
        :param pulumi.Input[str] organizational_unit: Name of the Organizational Unit under which the account resides.
        :param pulumi.Input[str] organizational_unit_id_on_delete: ID of the Organizational Unit to which the account should be moved when the resource is deleted. If no value is
               provided, the account will not be moved.
        :param pulumi.Input[str] path_id: Name of the path identifier of the product. This value is optional if the product has a default path, and required if
               the product has more than one path. To list the paths for a product, use ListLaunchPaths.
        :param pulumi.Input[str] provisioned_product_name: Name of the service catalog product that is provisioned. Defaults to a slugified version of the account name.
        :param pulumi.Input[pulumi.InputType['ControlTowerAwsAccountSsoArgs']] sso: Assigned SSO user settings.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value map of resource tags for the account.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ControlTowerAwsAccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a ControlTowerAwsAccount resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param ControlTowerAwsAccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ControlTowerAwsAccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 close_account_on_delete: Optional[pulumi.Input[bool]] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organizational_unit: Optional[pulumi.Input[str]] = None,
                 organizational_unit_id_on_delete: Optional[pulumi.Input[str]] = None,
                 path_id: Optional[pulumi.Input[str]] = None,
                 provisioned_product_name: Optional[pulumi.Input[str]] = None,
                 sso: Optional[pulumi.Input[pulumi.InputType['ControlTowerAwsAccountSsoArgs']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ControlTowerAwsAccountArgs.__new__(ControlTowerAwsAccountArgs)

            __props__.__dict__["close_account_on_delete"] = close_account_on_delete
            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            __props__.__dict__["name"] = name
            if organizational_unit is None and not opts.urn:
                raise TypeError("Missing required property 'organizational_unit'")
            __props__.__dict__["organizational_unit"] = organizational_unit
            __props__.__dict__["organizational_unit_id_on_delete"] = organizational_unit_id_on_delete
            __props__.__dict__["path_id"] = path_id
            __props__.__dict__["provisioned_product_name"] = provisioned_product_name
            if sso is None and not opts.urn:
                raise TypeError("Missing required property 'sso'")
            __props__.__dict__["sso"] = sso
            __props__.__dict__["tags"] = tags
            __props__.__dict__["account_id"] = None
        super(ControlTowerAwsAccount, __self__).__init__(
            'awscontroltower:index/controlTowerAwsAccount:controlTowerAwsAccount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[str]] = None,
            close_account_on_delete: Optional[pulumi.Input[bool]] = None,
            email: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            organizational_unit: Optional[pulumi.Input[str]] = None,
            organizational_unit_id_on_delete: Optional[pulumi.Input[str]] = None,
            path_id: Optional[pulumi.Input[str]] = None,
            provisioned_product_name: Optional[pulumi.Input[str]] = None,
            sso: Optional[pulumi.Input[pulumi.InputType['ControlTowerAwsAccountSsoArgs']]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None) -> 'ControlTowerAwsAccount':
        """
        Get an existing ControlTowerAwsAccount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account_id: ID of the AWS account.
        :param pulumi.Input[bool] close_account_on_delete: If enabled, this will close the AWS account on resource deletion, beginning the 90-day suspension period. Otherwise, the
               account will just be unenrolled from Control Tower.
        :param pulumi.Input[str] email: Root email of the account.
        :param pulumi.Input[str] name: Name of the account.
        :param pulumi.Input[str] organizational_unit: Name of the Organizational Unit under which the account resides.
        :param pulumi.Input[str] organizational_unit_id_on_delete: ID of the Organizational Unit to which the account should be moved when the resource is deleted. If no value is
               provided, the account will not be moved.
        :param pulumi.Input[str] path_id: Name of the path identifier of the product. This value is optional if the product has a default path, and required if
               the product has more than one path. To list the paths for a product, use ListLaunchPaths.
        :param pulumi.Input[str] provisioned_product_name: Name of the service catalog product that is provisioned. Defaults to a slugified version of the account name.
        :param pulumi.Input[pulumi.InputType['ControlTowerAwsAccountSsoArgs']] sso: Assigned SSO user settings.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value map of resource tags for the account.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ControlTowerAwsAccountState.__new__(_ControlTowerAwsAccountState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["close_account_on_delete"] = close_account_on_delete
        __props__.__dict__["email"] = email
        __props__.__dict__["name"] = name
        __props__.__dict__["organizational_unit"] = organizational_unit
        __props__.__dict__["organizational_unit_id_on_delete"] = organizational_unit_id_on_delete
        __props__.__dict__["path_id"] = path_id
        __props__.__dict__["provisioned_product_name"] = provisioned_product_name
        __props__.__dict__["sso"] = sso
        __props__.__dict__["tags"] = tags
        return ControlTowerAwsAccount(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[str]:
        """
        ID of the AWS account.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="closeAccountOnDelete")
    def close_account_on_delete(self) -> pulumi.Output[Optional[bool]]:
        """
        If enabled, this will close the AWS account on resource deletion, beginning the 90-day suspension period. Otherwise, the
        account will just be unenrolled from Control Tower.
        """
        return pulumi.get(self, "close_account_on_delete")

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[str]:
        """
        Root email of the account.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the account.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationalUnit")
    def organizational_unit(self) -> pulumi.Output[str]:
        """
        Name of the Organizational Unit under which the account resides.
        """
        return pulumi.get(self, "organizational_unit")

    @property
    @pulumi.getter(name="organizationalUnitIdOnDelete")
    def organizational_unit_id_on_delete(self) -> pulumi.Output[Optional[str]]:
        """
        ID of the Organizational Unit to which the account should be moved when the resource is deleted. If no value is
        provided, the account will not be moved.
        """
        return pulumi.get(self, "organizational_unit_id_on_delete")

    @property
    @pulumi.getter(name="pathId")
    def path_id(self) -> pulumi.Output[str]:
        """
        Name of the path identifier of the product. This value is optional if the product has a default path, and required if
        the product has more than one path. To list the paths for a product, use ListLaunchPaths.
        """
        return pulumi.get(self, "path_id")

    @property
    @pulumi.getter(name="provisionedProductName")
    def provisioned_product_name(self) -> pulumi.Output[str]:
        """
        Name of the service catalog product that is provisioned. Defaults to a slugified version of the account name.
        """
        return pulumi.get(self, "provisioned_product_name")

    @property
    @pulumi.getter
    def sso(self) -> pulumi.Output['outputs.ControlTowerAwsAccountSso']:
        """
        Assigned SSO user settings.
        """
        return pulumi.get(self, "sso")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Key-value map of resource tags for the account.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from ._inputs import *

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 region: pulumi.Input[str],
                 access_key: Optional[pulumi.Input[str]] = None,
                 assume_role: Optional[pulumi.Input['ProviderAssumeRoleArgs']] = None,
                 max_retries: Optional[pulumi.Input[int]] = None,
                 profile: Optional[pulumi.Input[str]] = None,
                 secret_key: Optional[pulumi.Input[str]] = None,
                 shared_credentials_file: Optional[pulumi.Input[str]] = None,
                 skip_credentials_validation: Optional[pulumi.Input[bool]] = None,
                 skip_metadata_api_check: Optional[pulumi.Input[bool]] = None,
                 skip_requesting_account_id: Optional[pulumi.Input[bool]] = None,
                 token: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[str] region: This is the AWS region. It must be provided, but it can also be sourced from the `AWS_DEFAULT_REGION` environment
               variables, or via a shared credentials file if `profile` is specified.
        :param pulumi.Input[str] access_key: This is the AWS access key. It must be provided, but it can also be sourced from the `AWS_ACCESS_KEY_ID` environment
               variable, or via a shared credentials file if `profile` is specified.
        :param pulumi.Input['ProviderAssumeRoleArgs'] assume_role: Settings for making use of the AWS Assume Role functionality.
        :param pulumi.Input[int] max_retries: This is the maximum number of times an API call is retried, in the case where requests are being throttled or
               experiencing transient failures. The delay between the subsequent API calls increases exponentially. If omitted, the
               default value is `25`.
        :param pulumi.Input[str] profile: This is the AWS profile name as set in the shared credentials file.
        :param pulumi.Input[str] secret_key: This is the AWS secret key. It must be provided, but it can also be sourced from the `AWS_SECRET_ACCESS_KEY` environment
               variable, or via a shared credentials file if `profile` is specified.
        :param pulumi.Input[str] shared_credentials_file: This is the path to the shared credentials file. If this is not set and a profile is specified, `~/.aws/credentials`
               will be used.
        :param pulumi.Input[bool] skip_credentials_validation: Skip the credentials validation via the STS API. Useful for AWS API implementations that do not have STS available or
               implemented.
        :param pulumi.Input[bool] skip_metadata_api_check: Skip the AWS Metadata API check. Useful for AWS API implementations that do not have a metadata API endpoint. Setting to
               `true` prevents Terraform from authenticating via the Metadata API. You may need to use other authentication methods
               like static credentials, configuration variables, or environment variables.
        :param pulumi.Input[bool] skip_requesting_account_id: Skip requesting the account ID. Useful for AWS API implementations that do not have the IAM, STS API, or metadata API.
        :param pulumi.Input[str] token: Session token for validating temporary credentials. Typically provided after successful identity federation or
               Multi-Factor Authentication (MFA) login. With MFA login, this is the session token provided afterward, not the 6 digit
               MFA code used to get temporary credentials. It can also be sourced from the `AWS_SESSION_TOKEN` environment variable.
        """
        pulumi.set(__self__, "region", region)
        if access_key is not None:
            pulumi.set(__self__, "access_key", access_key)
        if assume_role is not None:
            pulumi.set(__self__, "assume_role", assume_role)
        if max_retries is not None:
            pulumi.set(__self__, "max_retries", max_retries)
        if profile is not None:
            pulumi.set(__self__, "profile", profile)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)
        if shared_credentials_file is not None:
            pulumi.set(__self__, "shared_credentials_file", shared_credentials_file)
        if skip_credentials_validation is not None:
            pulumi.set(__self__, "skip_credentials_validation", skip_credentials_validation)
        if skip_metadata_api_check is not None:
            pulumi.set(__self__, "skip_metadata_api_check", skip_metadata_api_check)
        if skip_requesting_account_id is not None:
            pulumi.set(__self__, "skip_requesting_account_id", skip_requesting_account_id)
        if token is not None:
            pulumi.set(__self__, "token", token)

    @property
    @pulumi.getter
    def region(self) -> pulumi.Input[str]:
        """
        This is the AWS region. It must be provided, but it can also be sourced from the `AWS_DEFAULT_REGION` environment
        variables, or via a shared credentials file if `profile` is specified.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: pulumi.Input[str]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> Optional[pulumi.Input[str]]:
        """
        This is the AWS access key. It must be provided, but it can also be sourced from the `AWS_ACCESS_KEY_ID` environment
        variable, or via a shared credentials file if `profile` is specified.
        """
        return pulumi.get(self, "access_key")

    @access_key.setter
    def access_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_key", value)

    @property
    @pulumi.getter(name="assumeRole")
    def assume_role(self) -> Optional[pulumi.Input['ProviderAssumeRoleArgs']]:
        """
        Settings for making use of the AWS Assume Role functionality.
        """
        return pulumi.get(self, "assume_role")

    @assume_role.setter
    def assume_role(self, value: Optional[pulumi.Input['ProviderAssumeRoleArgs']]):
        pulumi.set(self, "assume_role", value)

    @property
    @pulumi.getter(name="maxRetries")
    def max_retries(self) -> Optional[pulumi.Input[int]]:
        """
        This is the maximum number of times an API call is retried, in the case where requests are being throttled or
        experiencing transient failures. The delay between the subsequent API calls increases exponentially. If omitted, the
        default value is `25`.
        """
        return pulumi.get(self, "max_retries")

    @max_retries.setter
    def max_retries(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_retries", value)

    @property
    @pulumi.getter
    def profile(self) -> Optional[pulumi.Input[str]]:
        """
        This is the AWS profile name as set in the shared credentials file.
        """
        return pulumi.get(self, "profile")

    @profile.setter
    def profile(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "profile", value)

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[pulumi.Input[str]]:
        """
        This is the AWS secret key. It must be provided, but it can also be sourced from the `AWS_SECRET_ACCESS_KEY` environment
        variable, or via a shared credentials file if `profile` is specified.
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret_key", value)

    @property
    @pulumi.getter(name="sharedCredentialsFile")
    def shared_credentials_file(self) -> Optional[pulumi.Input[str]]:
        """
        This is the path to the shared credentials file. If this is not set and a profile is specified, `~/.aws/credentials`
        will be used.
        """
        return pulumi.get(self, "shared_credentials_file")

    @shared_credentials_file.setter
    def shared_credentials_file(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "shared_credentials_file", value)

    @property
    @pulumi.getter(name="skipCredentialsValidation")
    def skip_credentials_validation(self) -> Optional[pulumi.Input[bool]]:
        """
        Skip the credentials validation via the STS API. Useful for AWS API implementations that do not have STS available or
        implemented.
        """
        return pulumi.get(self, "skip_credentials_validation")

    @skip_credentials_validation.setter
    def skip_credentials_validation(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "skip_credentials_validation", value)

    @property
    @pulumi.getter(name="skipMetadataApiCheck")
    def skip_metadata_api_check(self) -> Optional[pulumi.Input[bool]]:
        """
        Skip the AWS Metadata API check. Useful for AWS API implementations that do not have a metadata API endpoint. Setting to
        `true` prevents Terraform from authenticating via the Metadata API. You may need to use other authentication methods
        like static credentials, configuration variables, or environment variables.
        """
        return pulumi.get(self, "skip_metadata_api_check")

    @skip_metadata_api_check.setter
    def skip_metadata_api_check(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "skip_metadata_api_check", value)

    @property
    @pulumi.getter(name="skipRequestingAccountId")
    def skip_requesting_account_id(self) -> Optional[pulumi.Input[bool]]:
        """
        Skip requesting the account ID. Useful for AWS API implementations that do not have the IAM, STS API, or metadata API.
        """
        return pulumi.get(self, "skip_requesting_account_id")

    @skip_requesting_account_id.setter
    def skip_requesting_account_id(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "skip_requesting_account_id", value)

    @property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[str]]:
        """
        Session token for validating temporary credentials. Typically provided after successful identity federation or
        Multi-Factor Authentication (MFA) login. With MFA login, this is the session token provided afterward, not the 6 digit
        MFA code used to get temporary credentials. It can also be sourced from the `AWS_SESSION_TOKEN` environment variable.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token", value)


class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key: Optional[pulumi.Input[str]] = None,
                 assume_role: Optional[pulumi.Input[pulumi.InputType['ProviderAssumeRoleArgs']]] = None,
                 max_retries: Optional[pulumi.Input[int]] = None,
                 profile: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 secret_key: Optional[pulumi.Input[str]] = None,
                 shared_credentials_file: Optional[pulumi.Input[str]] = None,
                 skip_credentials_validation: Optional[pulumi.Input[bool]] = None,
                 skip_metadata_api_check: Optional[pulumi.Input[bool]] = None,
                 skip_requesting_account_id: Optional[pulumi.Input[bool]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The provider type for the awscontroltower package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_key: This is the AWS access key. It must be provided, but it can also be sourced from the `AWS_ACCESS_KEY_ID` environment
               variable, or via a shared credentials file if `profile` is specified.
        :param pulumi.Input[pulumi.InputType['ProviderAssumeRoleArgs']] assume_role: Settings for making use of the AWS Assume Role functionality.
        :param pulumi.Input[int] max_retries: This is the maximum number of times an API call is retried, in the case where requests are being throttled or
               experiencing transient failures. The delay between the subsequent API calls increases exponentially. If omitted, the
               default value is `25`.
        :param pulumi.Input[str] profile: This is the AWS profile name as set in the shared credentials file.
        :param pulumi.Input[str] region: This is the AWS region. It must be provided, but it can also be sourced from the `AWS_DEFAULT_REGION` environment
               variables, or via a shared credentials file if `profile` is specified.
        :param pulumi.Input[str] secret_key: This is the AWS secret key. It must be provided, but it can also be sourced from the `AWS_SECRET_ACCESS_KEY` environment
               variable, or via a shared credentials file if `profile` is specified.
        :param pulumi.Input[str] shared_credentials_file: This is the path to the shared credentials file. If this is not set and a profile is specified, `~/.aws/credentials`
               will be used.
        :param pulumi.Input[bool] skip_credentials_validation: Skip the credentials validation via the STS API. Useful for AWS API implementations that do not have STS available or
               implemented.
        :param pulumi.Input[bool] skip_metadata_api_check: Skip the AWS Metadata API check. Useful for AWS API implementations that do not have a metadata API endpoint. Setting to
               `true` prevents Terraform from authenticating via the Metadata API. You may need to use other authentication methods
               like static credentials, configuration variables, or environment variables.
        :param pulumi.Input[bool] skip_requesting_account_id: Skip requesting the account ID. Useful for AWS API implementations that do not have the IAM, STS API, or metadata API.
        :param pulumi.Input[str] token: Session token for validating temporary credentials. Typically provided after successful identity federation or
               Multi-Factor Authentication (MFA) login. With MFA login, this is the session token provided afterward, not the 6 digit
               MFA code used to get temporary credentials. It can also be sourced from the `AWS_SESSION_TOKEN` environment variable.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProviderArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the awscontroltower package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key: Optional[pulumi.Input[str]] = None,
                 assume_role: Optional[pulumi.Input[pulumi.InputType['ProviderAssumeRoleArgs']]] = None,
                 max_retries: Optional[pulumi.Input[int]] = None,
                 profile: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 secret_key: Optional[pulumi.Input[str]] = None,
                 shared_credentials_file: Optional[pulumi.Input[str]] = None,
                 skip_credentials_validation: Optional[pulumi.Input[bool]] = None,
                 skip_metadata_api_check: Optional[pulumi.Input[bool]] = None,
                 skip_requesting_account_id: Optional[pulumi.Input[bool]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["access_key"] = access_key
            __props__.__dict__["assume_role"] = pulumi.Output.from_input(assume_role).apply(pulumi.runtime.to_json) if assume_role is not None else None
            __props__.__dict__["max_retries"] = pulumi.Output.from_input(max_retries).apply(pulumi.runtime.to_json) if max_retries is not None else None
            __props__.__dict__["profile"] = profile
            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__.__dict__["region"] = region
            __props__.__dict__["secret_key"] = secret_key
            __props__.__dict__["shared_credentials_file"] = shared_credentials_file
            __props__.__dict__["skip_credentials_validation"] = pulumi.Output.from_input(skip_credentials_validation).apply(pulumi.runtime.to_json) if skip_credentials_validation is not None else None
            __props__.__dict__["skip_metadata_api_check"] = pulumi.Output.from_input(skip_metadata_api_check).apply(pulumi.runtime.to_json) if skip_metadata_api_check is not None else None
            __props__.__dict__["skip_requesting_account_id"] = pulumi.Output.from_input(skip_requesting_account_id).apply(pulumi.runtime.to_json) if skip_requesting_account_id is not None else None
            __props__.__dict__["token"] = token
        super(Provider, __self__).__init__(
            'awscontroltower',
            resource_name,
            __props__,
            opts)

    @property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> pulumi.Output[Optional[str]]:
        """
        This is the AWS access key. It must be provided, but it can also be sourced from the `AWS_ACCESS_KEY_ID` environment
        variable, or via a shared credentials file if `profile` is specified.
        """
        return pulumi.get(self, "access_key")

    @property
    @pulumi.getter
    def profile(self) -> pulumi.Output[Optional[str]]:
        """
        This is the AWS profile name as set in the shared credentials file.
        """
        return pulumi.get(self, "profile")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[str]:
        """
        This is the AWS region. It must be provided, but it can also be sourced from the `AWS_DEFAULT_REGION` environment
        variables, or via a shared credentials file if `profile` is specified.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Output[Optional[str]]:
        """
        This is the AWS secret key. It must be provided, but it can also be sourced from the `AWS_SECRET_ACCESS_KEY` environment
        variable, or via a shared credentials file if `profile` is specified.
        """
        return pulumi.get(self, "secret_key")

    @property
    @pulumi.getter(name="sharedCredentialsFile")
    def shared_credentials_file(self) -> pulumi.Output[Optional[str]]:
        """
        This is the path to the shared credentials file. If this is not set and a profile is specified, `~/.aws/credentials`
        will be used.
        """
        return pulumi.get(self, "shared_credentials_file")

    @property
    @pulumi.getter
    def token(self) -> pulumi.Output[Optional[str]]:
        """
        Session token for validating temporary credentials. Typically provided after successful identity federation or
        Multi-Factor Authentication (MFA) login. With MFA login, this is the session token provided afterward, not the 6 digit
        MFA code used to get temporary credentials. It can also be sourced from the `AWS_SESSION_TOKEN` environment variable.
        """
        return pulumi.get(self, "token")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'ProviderAssumeRoleArgs',
    'ControlTowerAwsAccountSsoArgs',
]

@pulumi.input_type
class ProviderAssumeRoleArgs:
    def __init__(__self__, *,
                 duration_seconds: Optional[pulumi.Input[int]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 policy_arns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 role_arn: Optional[pulumi.Input[str]] = None,
                 session_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 transitive_tag_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        if duration_seconds is not None:
            pulumi.set(__self__, "duration_seconds", duration_seconds)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if policy_arns is not None:
            pulumi.set(__self__, "policy_arns", policy_arns)
        if role_arn is not None:
            pulumi.set(__self__, "role_arn", role_arn)
        if session_name is not None:
            pulumi.set(__self__, "session_name", session_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transitive_tag_keys is not None:
            pulumi.set(__self__, "transitive_tag_keys", transitive_tag_keys)

    @property
    @pulumi.getter(name="durationSeconds")
    def duration_seconds(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "duration_seconds")

    @duration_seconds.setter
    def duration_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration_seconds", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter(name="policyArns")
    def policy_arns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "policy_arns")

    @policy_arns.setter
    def policy_arns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "policy_arns", value)

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_arn", value)

    @property
    @pulumi.getter(name="sessionName")
    def session_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "session_name")

    @session_name.setter
    def session_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "session_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitiveTagKeys")
    def transitive_tag_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "transitive_tag_keys")

    @transitive_tag_keys.setter
    def transitive_tag_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "transitive_tag_keys", value)


@pulumi.input_type
class ControlTowerAwsAccountSsoArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[str],
                 first_name: pulumi.Input[str],
                 last_name: pulumi.Input[str]):
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "first_name", first_name)
        pulumi.set(__self__, "last_name", last_name)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[str]:
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "first_name", value)

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "last_name", value)


